@@ -55,6 +55,11 @@ card_template="""
             </td>
 """
 
+card_empty_template="""
+    <table class=bchand style="border-collapse: collapse; border-spacing: 0">
+    </table>
+"""
+
 board_template="""
               <table class=bcct style="width: 4em; height: 4em; border-collapse: collapse; font: 10pt simsun, sans-serif; color: #ffffff; border: 1px solid #aaaaaa">
                 <tr class=bcct1>
@@ -251,31 +256,39 @@ def pbn_html_auction(pbn):
     tags = pbn["tags"]
     section_auction = pbn["section_auction"]
     all["auction"] = html_auction(tags["Auction"], section_auction)
-    if "pbn2html" in os.environ.get("_"):
-        template = pkgutil.get_data(__name__,'auction_template.html')
-        src = Template(template.decode('utf-8'))
-    else:
-        template = open("auction_template.html", "r",encoding="utf-8").read()
-        src = Template(template)
+    template = pkgutil.get_data(__name__,'auction_template.html')
+    src = Template(template.decode('utf-8'))
     result = src.safe_substitute(all)
     return result
 
-def pbn_html_deal(pbn):
+def pbn_html_deal(pbn, cards="NESW"):
     all = {}
     tags = pbn["tags"]
     hands = pbn["hands"]
+    empty_hand = card_empty_template
+    # print(hands["N"])
+
     all["north"] = html_card(hands["N"])
     all["west"] = html_card(hands["W"])
     all["east"] = html_card(hands["E"])
     all["south"] = html_card(hands["S"])
+    for card in "NESW":
+        if card not in cards:
+            if card == "N":
+                all["north"] = empty_hand
+            if card == "W":
+                all["west"] = empty_hand
+            if card == "E":
+                all["east"] = empty_hand
+            if card == "S":
+                all["south"] = empty_hand
+
     all["board"] = html_board(tags["Vulnerable"],tags["Dealer"])
     all["extra"] = html_extra(tags["Contract"],tags["Declarer"])
-    if "pbn2html" in os.environ.get("_"):
-        template = pkgutil.get_data(__name__,'deal_template.html')
-        src = Template(template.decode('utf-8'))
-    else:
-        template = open("deal_template.html", "r",encoding="utf-8").read()
-        src = Template(template)
+    template = pkgutil.get_data(__name__,'deal_template.html')
+    #template = open("deal_template.html", "r", encoding="utf-8").read()
+    #src = Template(template)
+    src = Template(template.decode('utf-8'))
     result = src.safe_substitute(all)
     return result
 
@@ -291,12 +304,8 @@ def pbn_html_all(pbn):
     all["board"] = html_board(tags["Vulnerable"],tags["Dealer"])
     all["extra"] = html_extra(tags["Contract"],tags["Declarer"])
     all["auction"] = html_auction(tags["Auction"], section_auction)
-    if "pbn2html" in os.environ.get("_"):
-        template = pkgutil.get_data(__name__,'all_template.html')
-        src = Template(template.decode('utf-8'))
-    else:
-        template = open("all_template.html", "r",encoding="utf-8").read()
-        src = Template(template)
+    template = pkgutil.get_data(__name__,'all_template.html')
+    src = Template(template.decode('utf-8'))
     result = src.safe_substitute(all)
     return result
 
@@ -306,9 +315,13 @@ def main():
         param = sys.argv[1:]
         if param[0].endswith(".pbn"):
             pbn2html(param[0])
-            #pbn = get_from_pbn_file(param[0])
+            pbn = get_from_pbn_file(param[0])
             #print(pbn_html_all(pbn))
             #print(pbn_html_auction(pbn))
+            
+            #print(pbn_html_deal(pbn, cards="NS"))
+            #print(pbn_html_deal(pbn, cards="EW"))
+            #print(pbn_html_deal(pbn, cards="NEWS"))
             #print(pbn_html_deal(pbn))
         else:
             print("pbn2html.py <file.pbn>")
